Exception: WSDL::Error

Inherits:
StandardError
  • Object
show all
Defined in:
lib/wsdl/errors.rb

Overview

Base error class for all WSDL-related errors.

All custom exceptions raised by this library inherit from this class, making it easy to rescue all WSDL errors with a single rescue clause.

Examples:

Rescuing all WSDL errors

begin
  client = WSDL::Client.new('http://example.com/service?wsdl')
  operation = client.operation('Service', 'Port', 'Operation')
  operation.invoke
rescue WSDL::Error => e
  puts "WSDL error: #{e.message}"
end