Exception: WSDL::FatalError
Overview
Base class for non-recoverable WSDL errors.
Fatal errors indicate security violations or hard safety constraints that should never be silently skipped.
Base class for non-recoverable WSDL errors.
Fatal errors indicate security violations or hard safety constraints that should never be silently skipped.