Class: WSDL::Parser::PortType Private

Inherits:
Object
  • Object
show all
Defined in:
lib/wsdl/parser/port_type.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Represents a WSDL portType element.

A port type defines an abstract set of operations supported by one or more endpoints. Each operation specifies input and output messages that define the interface contract, independent of protocol bindings.

Instance Method Summary collapse

Constructor Details

#initialize(port_type_node) ⇒ PortType

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Creates a new PortType from a WSDL portType XML node.

Parameters:

  • port_type_node (Nokogiri::XML::Node)

    the wsdl:portType element



17
18
19
# File 'lib/wsdl/parser/port_type.rb', line 17

def initialize(port_type_node)
  @port_type_node = port_type_node
end

Instance Method Details

#nameString

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns the name of this port type.

Returns:

  • (String)

    the port type name



24
25
26
# File 'lib/wsdl/parser/port_type.rb', line 24

def name
  @port_type_node['name']
end

#operationsHash{String => PortTypeOperation}

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns the operations defined in this port type.

Returns:

  • (Hash{String => PortTypeOperation})

    a hash of operation names to port type operations



31
32
33
# File 'lib/wsdl/parser/port_type.rb', line 31

def operations
  @operations ||= operations!
end