Exception: WSDL::SchemaImportError

Inherits:
Error
  • Object
show all
Defined in:
lib/wsdl/errors.rb

Overview

Raised when an imported schema cannot be fetched or parsed.

This error wraps recoverable schema import failures (for example missing files, network timeouts, or malformed imported XSD documents).

When strictness.schema_imports is false, these errors are logged and skipped. When true (default), they are raised.

Direct Known Subclasses

SchemaImportParseError

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(message = nil, location: nil, base_location: nil, action: nil) ⇒ SchemaImportError

Creates a new SchemaImportError.

Parameters:

  • message (String) (defaults to: nil)

    error message

  • location (String, nil) (defaults to: nil)

    schema location that failed

  • base_location (String, nil) (defaults to: nil)

    resolution base location

  • action (String, nil) (defaults to: nil)

    import action (import or include)



62
63
64
65
66
67
# File 'lib/wsdl/errors.rb', line 62

def initialize(message = nil, location: nil, base_location: nil, action: nil)
  @location = location
  @base_location = base_location
  @action = action
  super(message)
end

Instance Attribute Details

#actionString? (readonly)

Returns import action (import or include).

Returns:

  • (String, nil)

    import action (import or include)



54
55
56
# File 'lib/wsdl/errors.rb', line 54

def action
  @action
end

#base_locationString? (readonly)

Returns parent document location used as resolution base.

Returns:

  • (String, nil)

    parent document location used as resolution base



51
52
53
# File 'lib/wsdl/errors.rb', line 51

def base_location
  @base_location
end

#locationString? (readonly)

Returns schema location that failed.

Returns:

  • (String, nil)

    schema location that failed



48
49
50
# File 'lib/wsdl/errors.rb', line 48

def location
  @location
end