Class: WSDL::Security::ResponseVerification::Timestamp

Inherits:
Data
  • Object
show all
Defined in:
lib/wsdl/security/response_verification.rb

Overview

Timestamp freshness verification options.

WS-Security timestamps contain Created and Expires times that can be validated to prevent replay attacks and ensure message freshness.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#tolerance_secondsObject (readonly)

Returns the value of attribute tolerance_seconds

Returns:

  • (Object)

    the current value of tolerance_seconds



49
50
51
52
53
54
55
56
57
# File 'lib/wsdl/security/response_verification.rb', line 49

Timestamp = Data.define(:validate, :tolerance_seconds) {
  # Returns default timestamp verification options.
  #
  # @return [Timestamp] defaults with validation enabled and 5-minute tolerance
  #
  def self.default
    new(validate: true, tolerance_seconds: 300)
  end
}

#validateObject (readonly)

Returns the value of attribute validate

Returns:

  • (Object)

    the current value of validate



49
50
51
52
53
54
55
56
57
# File 'lib/wsdl/security/response_verification.rb', line 49

Timestamp = Data.define(:validate, :tolerance_seconds) {
  # Returns default timestamp verification options.
  #
  # @return [Timestamp] defaults with validation enabled and 5-minute tolerance
  #
  def self.default
    new(validate: true, tolerance_seconds: 300)
  end
}

Class Method Details

.defaultTimestamp

Returns default timestamp verification options.

Returns:

  • (Timestamp)

    defaults with validation enabled and 5-minute tolerance



54
55
56
# File 'lib/wsdl/security/response_verification.rb', line 54

def self.default
  new(validate: true, tolerance_seconds: 300)
end