Exception: WSDL::SignatureVerificationError

Inherits:
SecurityError show all
Defined in:
lib/wsdl/errors.rb

Overview

Raised when signature verification fails on a response.

This error is raised when:

  • The response does not contain a signature when one is expected
  • The signature verification process fails
  • SignedInfo does not reference the SOAP Body
  • The digest values do not match the signed content

Examples:

begin
  response.security.verify_signature!
rescue WSDL::SignatureVerificationError => e
  log_security_event("Signature verification failed: #{e.message}")
end