Class: WSDL::Parser::MessageInfo Private
- Inherits:
-
Object
- Object
- WSDL::Parser::MessageInfo
- Defined in:
- lib/wsdl/parser/message_info.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Represents a WSDL message element.
A message in WSDL defines the abstract structure of data being exchanged. It consists of one or more parts, each of which may reference an XML Schema type or element.
Instance Method Summary collapse
-
#initialize(message_node) ⇒ MessageInfo
constructor
private
Creates a new MessageInfo from a WSDL message XML node.
-
#name ⇒ String
private
Returns the name of this message.
-
#parts ⇒ Array<Hash>
private
Returns the parts defined in this message.
Constructor Details
#initialize(message_node) ⇒ MessageInfo
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Creates a new MessageInfo from a WSDL message XML node.
17 18 19 |
# File 'lib/wsdl/parser/message_info.rb', line 17 def initialize() = end |
Instance Method Details
#name ⇒ String
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns the name of this message.
24 25 26 |
# File 'lib/wsdl/parser/message_info.rb', line 24 def name ['name'] end |
#parts ⇒ Array<Hash>
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns the parts defined in this message.
Each part is a Hash with the following keys:
:name- the part name:type- the qualified type name (if using type attribute):element- the qualified element name (if using element attribute):namespaces- the namespace declarations in scope
37 38 39 |
# File 'lib/wsdl/parser/message_info.rb', line 37 def parts @parts ||= parts! end |