Class: WSDL::Parser::Output Private
- Inherits:
-
MessageParts
- Object
- MessageParts
- WSDL::Parser::Output
- Defined in:
- lib/wsdl/parser/input_output.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Represents the output message definition for an operation.
Processes the binding and port type operation definitions to build the header and body parts for response messages.
Instance Attribute Summary
Attributes inherited from MessageParts
Method Summary
Methods inherited from MessageParts
Constructor Details
This class inherits a constructor from WSDL::Parser::MessageParts