Class: WSDL::Parser::PortType Private
- Inherits:
-
Object
- Object
- WSDL::Parser::PortType
- Defined in:
- lib/wsdl/parser/port_type.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Represents a WSDL portType element.
A port type defines an abstract set of operations supported by one or more endpoints. Each operation specifies input and output messages that define the interface contract, independent of protocol bindings.
Instance Method Summary collapse
-
#initialize(port_type_node) ⇒ PortType
constructor
private
Creates a new PortType from a WSDL portType XML node.
-
#name ⇒ String
private
Returns the name of this port type.
-
#operations ⇒ Hash{String => PortTypeOperation}
private
Returns the operations defined in this port type.
Constructor Details
#initialize(port_type_node) ⇒ PortType
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Creates a new PortType from a WSDL portType XML node.
17 18 19 |
# File 'lib/wsdl/parser/port_type.rb', line 17 def initialize(port_type_node) @port_type_node = port_type_node end |
Instance Method Details
#name ⇒ String
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns the name of this port type.
24 25 26 |
# File 'lib/wsdl/parser/port_type.rb', line 24 def name @port_type_node['name'] end |
#operations ⇒ Hash{String => PortTypeOperation}
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns the operations defined in this port type.
31 32 33 |
# File 'lib/wsdl/parser/port_type.rb', line 31 def operations @operations ||= operations! end |