Class: WSDL::Parser::PortTypeOperation Private
- Inherits:
-
Object
- Object
- WSDL::Parser::PortTypeOperation
- Defined in:
- lib/wsdl/parser/port_type_operation.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Represents a WSDL portType operation element.
A port type operation defines an abstract operation as part of a port type interface. It specifies the input and output messages that define the operation's interface contract, independent of any protocol binding.
Instance Attribute Summary collapse
-
#name ⇒ String
readonly
private
The name of this operation.
Instance Method Summary collapse
-
#initialize(operation_node, namespaces: nil) ⇒ PortTypeOperation
constructor
private
Creates a new PortTypeOperation from a WSDL operation XML node.
-
#input ⇒ MessageReference
private
Returns the input message definition for this operation.
-
#input_name ⇒ String?
private
Returns the name attribute of the input element.
-
#output ⇒ MessageReference
private
Returns the output message definition for this operation.
Constructor Details
#initialize(operation_node, namespaces: nil) ⇒ PortTypeOperation
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Creates a new PortTypeOperation from a WSDL operation XML node.
20 21 22 23 24 25 26 27 |
# File 'lib/wsdl/parser/port_type_operation.rb', line 20 def initialize(operation_node, namespaces: nil) @operation_node = operation_node @namespaces = namespaces @name = operation_node['name'] @input_node = find_node('input') @output_node = find_node('output') end |
Instance Attribute Details
#name ⇒ String (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns the name of this operation.
30 31 32 |
# File 'lib/wsdl/parser/port_type_operation.rb', line 30 def name @name end |
Instance Method Details
#input ⇒ MessageReference
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns the input message definition for this operation.
47 48 49 50 51 |
# File 'lib/wsdl/parser/port_type_operation.rb', line 47 def input return @input if defined? @input @input = @input_node ? parse_node(@input_node) : nil end |
#input_name ⇒ String?
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns the name attribute of the input element.
Used by OperationMap for overload disambiguation.
37 38 39 |
# File 'lib/wsdl/parser/port_type_operation.rb', line 37 def input_name input&.name end |
#output ⇒ MessageReference
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns the output message definition for this operation.
59 60 61 62 63 |
# File 'lib/wsdl/parser/port_type_operation.rb', line 59 def output return @output if defined? @output @output = @output_node ? parse_node(@output_node) : nil end |