Class: WSDL::Parser::PortTypeOperation Private

Inherits:
Object
  • Object
show all
Defined in:
lib/wsdl/parser/port_type_operation.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Represents a WSDL portType operation element.

A port type operation defines an abstract operation as part of a port type interface. It specifies the input and output messages that define the operation's interface contract, independent of any protocol binding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(operation_node) ⇒ PortTypeOperation

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Creates a new PortTypeOperation from a WSDL operation XML node.

Parameters:

  • operation_node (Nokogiri::XML::Node)

    the wsdl:operation element within a portType



18
19
20
21
22
23
24
# File 'lib/wsdl/parser/port_type_operation.rb', line 18

def initialize(operation_node)
  @operation_node = operation_node

  @name = operation_node['name']
  @input_node = find_node('input')
  @output_node = find_node('output')
end

Instance Attribute Details

#nameString (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns the name of this operation.

Returns:

  • (String)

    the name of this operation



27
28
29
# File 'lib/wsdl/parser/port_type_operation.rb', line 27

def name
  @name
end

Instance Method Details

#inputMessageReference

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns the input message definition for this operation.

Examples:

operation.input
# => #<data WSDL::Parser::MessageReference ...>

Returns:



35
36
37
38
39
# File 'lib/wsdl/parser/port_type_operation.rb', line 35

def input
  return @input if defined? @input

  @input = parse_node(@input_node)
end

#outputMessageReference

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns the output message definition for this operation.

Examples:

operation.output
# => #<data WSDL::Parser::MessageReference ...>

Returns:



47
48
49
50
51
# File 'lib/wsdl/parser/port_type_operation.rb', line 47

def output
  return @output if defined? @output

  @output = parse_node(@output_node)
end