Exception: WSDL::RequestDefinitionError
- Defined in:
- lib/wsdl/errors.rb
Overview
Raised when request definition is missing or structurally incomplete.
This error is raised when calling an operation that expects input but no request envelope has been defined via Operation#prepare.