Exception: WSDL::SchemaImportError

Inherits:
Error
  • Object
show all
Defined in:
lib/wsdl/errors.rb

Overview

Raised when an imported schema cannot be fetched or parsed.

This error wraps recoverable schema import failures (for example missing files, network timeouts, or malformed imported XSD documents).

In strict_schema: false mode these errors are logged and skipped. In strict_schema: true mode they are raised.

Direct Known Subclasses

SchemaImportParseError

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(message = nil, location: nil, base_location: nil, action: nil) ⇒ SchemaImportError

Creates a new SchemaImportError.

Parameters:

  • message (String) (defaults to: nil)

    error message

  • location (String, nil) (defaults to: nil)

    schema location that failed

  • base_location (String, nil) (defaults to: nil)

    resolution base location

  • action (String, nil) (defaults to: nil)

    import action (import or include)



60
61
62
63
64
65
# File 'lib/wsdl/errors.rb', line 60

def initialize(message = nil, location: nil, base_location: nil, action: nil)
  @location = location
  @base_location = base_location
  @action = action
  super(message)
end

Instance Attribute Details

#actionString? (readonly)

Returns import action (import or include).

Returns:

  • (String, nil)

    import action (import or include)



52
53
54
# File 'lib/wsdl/errors.rb', line 52

def action
  @action
end

#base_locationString? (readonly)

Returns parent document location used as resolution base.

Returns:

  • (String, nil)

    parent document location used as resolution base



49
50
51
# File 'lib/wsdl/errors.rb', line 49

def base_location
  @base_location
end

#locationString? (readonly)

Returns schema location that failed.

Returns:

  • (String, nil)

    schema location that failed



46
47
48
# File 'lib/wsdl/errors.rb', line 46

def location
  @location
end