Class: WSDL::Security::ResponseVerification::Timestamp
- Inherits:
-
Data
- Object
- Data
- WSDL::Security::ResponseVerification::Timestamp
- Defined in:
- lib/wsdl/security/response_verification.rb
Overview
Timestamp freshness verification options.
WS-Security timestamps contain Created and Expires times that can be validated to prevent replay attacks and ensure message freshness.
Instance Attribute Summary collapse
-
#tolerance_seconds ⇒ Object
readonly
Returns the value of attribute tolerance_seconds.
-
#validate ⇒ Object
readonly
Returns the value of attribute validate.
Class Method Summary collapse
-
.default ⇒ Timestamp
Returns default timestamp verification options.
Instance Attribute Details
#tolerance_seconds ⇒ Object (readonly)
Returns the value of attribute tolerance_seconds
49 50 51 52 53 54 55 56 57 |
# File 'lib/wsdl/security/response_verification.rb', line 49 Timestamp = Data.define(:validate, :tolerance_seconds) { # Returns default timestamp verification options. # # @return [Timestamp] defaults with validation enabled and 5-minute tolerance # def self.default new(validate: true, tolerance_seconds: 300) end } |
#validate ⇒ Object (readonly)
Returns the value of attribute validate
49 50 51 52 53 54 55 56 57 |
# File 'lib/wsdl/security/response_verification.rb', line 49 Timestamp = Data.define(:validate, :tolerance_seconds) { # Returns default timestamp verification options. # # @return [Timestamp] defaults with validation enabled and 5-minute tolerance # def self.default new(validate: true, tolerance_seconds: 300) end } |
Class Method Details
.default ⇒ Timestamp
Returns default timestamp verification options.
54 55 56 |
# File 'lib/wsdl/security/response_verification.rb', line 54 def self.default new(validate: true, tolerance_seconds: 300) end |