Class: WSDL::XML::Attribute Private
- Inherits:
-
Object
- Object
- WSDL::XML::Attribute
- Defined in:
- lib/wsdl/xml/attribute.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Represents an XML attribute definition used for building SOAP messages.
Attributes are defined on complex type elements and can be either required or optional. They are rendered as XML attributes on the parent element rather than as child elements.
Instance Attribute Summary collapse
-
#base_type ⇒ String
The base type name for this attribute (e.g., 'xsd:string').
-
#name ⇒ String
The local name of this attribute.
-
#use ⇒ String
The use constraint for this attribute ('optional' or 'required').
Instance Method Summary collapse
-
#optional? ⇒ Boolean
private
Returns whether this attribute is optional.
Instance Attribute Details
#base_type ⇒ String
The base type name for this attribute (e.g., 'xsd:string').
22 23 24 |
# File 'lib/wsdl/xml/attribute.rb', line 22 def base_type @base_type end |
#name ⇒ String
The local name of this attribute.
17 18 19 |
# File 'lib/wsdl/xml/attribute.rb', line 17 def name @name end |
#use ⇒ String
The use constraint for this attribute ('optional' or 'required'). Defaults to 'optional' if not specified in the schema.
28 29 30 |
# File 'lib/wsdl/xml/attribute.rb', line 28 def use @use end |
Instance Method Details
#optional? ⇒ Boolean
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns whether this attribute is optional.
33 34 35 |
# File 'lib/wsdl/xml/attribute.rb', line 33 def optional? use == 'optional' end |